<?php

namespace App;

use App\Order;
use Illuminate\Database\Eloquent\Model;

class Company extends Model
{
    public function deliverytimes(){
    	return $this->hasMany(Deliverytime::class);
    }

    public function deliveryareas(){
    	return $this->hasMany(Deliveryarea::class);
    }

    public function orders(){
    	return $this->hasMany(Order::class)->latest();
    }

    public function stocks(){
    	return $this->hasMany(Stock::class);
    }

    public function user(){
    	return $this->belongsTo(User::class);
    }

    public function fullAddress(){
        return ucfirst($this->street_address) . ", " . ucfirst($this->city) . ", " . ucfirst($this->state) . ", " . ucfirst($this->country);
    }

    public function getCompanyById($id){
        return $this->where('id', $id)->first();
    }

    public function pendingOrders($limit=20){
        return Order::where('status', 1)->where('company_id', $this->id)->latest()->paginate($limit);
    }

    public function countPendingOrders(){
        return Order::where('status', 1)->where('company_id', $this->id)->count();
    }

    public function completedOrders($limit=20){
        return Order::where('status', 2)->where('company_id', $this->id)->latest()->paginate($limit);
    }

    public function countCompletedOrders(){
        return Order::where('status', 2)->where('company_id', $this->id)->count();
    }

    public static function getCompanies($limit=20){
        return self::oldest()->paginate($limit);
    }

    /**
     * Get a company by slug
     * I most likely shouldn't be doing this, but just to be a bit lenient,
     * this method allows you get company by either slug or id
     *
     * @param string|integer $slug
     * @return App\Company
     */
    public function getCompanyBySlug($slug){
        // $company = $this->where('slug', $slug)->first();
        // if (is_null($company)){
            $company = $this->where('id', $slug)->firstOrFail();
        // }
        return $company;
    }

}
