<?php

namespace App\Http\Controllers\Auth;

use App\Category;
use App\Http\Controllers\Controller;
use Illuminate\Foundation\Auth\ResetsPasswords;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ResetPasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Password Reset Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling password reset requests
    | and uses a simple trait to include this behavior. You're free to
    | explore this trait and override any methods you wish to tweak.
    |
    */

    use ResetsPasswords;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Path to redirect to after resetting password
     *
     * @return string
     */
    public function redirectTo()
    {
        if (Auth::user()->hasRole('user')) {
            return '/patient';
        } elseif (Auth::user()->hasRole('pharmacy')) {
            return '/pharmacist';
        } elseif (Auth::user()->hasRole('admin')) {
            return '/administrator/dashboard';
        } else {
            // do nothing
        }
    }

    /**
     * Display the password reset view for the given token.
     *
     * If no token is present, display the link request form.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  string|null  $token
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function showResetForm(Request $request, $token = null)
    {
        $data = array();
        $data['categories'] = Category::with('stocks')->get();
        $data['token'] = $token;
        $data['email'] = $request->email;

        return view('auth.passwords.reset')->with($data);
    }
}
