<?php

namespace App\Http\Controllers\Pharmacy;

use App\Category;
use App\Http\Controllers\Controller;
use App\Stock;
use App\User;
use Illuminate\Http\Request;
use Prologue\Alerts\Facades\Alert;

class StockController extends Controller
{
    /**
     * @var App\Stock
     */
    protected $stock;

    public function __construct(Stock $stock){
        $this->stock = $stock;
    }
	/**
	 * Display all stocks available with pagination
	 * @return view
	 */
	public function index(){
        $stocks = $this->stock->where('company_id', auth()->user()->company->id)->paginate(20);
        // $stocks = $this->stock->paginate(20);
        $data['stocks'] = $stocks;
        return view('pharmacist.stock.index', $data);
	}

	/**
	 * Display a single stock item
	 * @param integer $id
	 * @return type
	 */
    public function show($id){
        $stock = $this->stock->getById($id);
        $data['stock'] = $stock;
        return view('pharmacist.stock.details', $data);
    }

    /**
     * Display form to add a new stock item
     * @return view
     */
    public function add(){
        $data = [];
        $data['categories'] = Category::all();
        $data['existingDrugs'] = Stock::all();
        return view('pharmacist.stock.new', $data);
    }

    /**
     * Store a single stock item in database
     * @param Request $request
     * @return redirect
     */
    public function store(Request $request){

        $this->validate($request, [
            'drug_name' => 'required|string|max:100',
            'drug_price' => 'required',
            'drug_quantity' => 'required|numeric',
            'drug_image' => 'required|image']);
        $user = User::find(auth()->id());
        $company = $user->company;
        $stock = new Stock;

        if (!is_null($request->drug_image)){
            $company_slug = str_slug($company->company_name);
            $file_path = $request->drug_image->store("{$company_slug}/products", "public");
            $stock->picture_path = $file_path;
        }

        $stock->name = $request->drug_name;
        $stock->slug = str_slug($stock->name);
        $stock->price = $request->drug_price;
        $stock->brand = $request->drug_brand;
        $stock->quantity = $request->drug_quantity;
        $stock->category_id = $request->drug_category;
        $stock->description = $request->product_description;
        $company->stocks()->save($stock);
        Alert::success('Stock Item has been added')->flash();
        return back();
    }

    /**
     * Display form to edit a stock item
     * @param type $id
     * @return view
     */
    public function edit($id){

    }

    /**
     * Update a single stock item
     * @param Request $request
     * @param integer $id
     * @return redirect
     */
    public function update(Request $request, $id){
        $this->validate($request, [
            'drug_name' => 'required|string|max:100',
            'drug_price' => 'required',
            'drug_quantity' => 'required|numeric']);
        $user = User::find(auth()->id());
        $company = $user->company;
        $stock = $this->stock->getById($id);

        if (!is_null($request->drug_image)){
            $company_slug = str_slug($company->company_name);
            $file_path = $request->drug_image->store("{$company_slug}/products", "public");
            $stock->picture_path = $file_path;
        }

        $stock->name = $request->drug_name;
        $stock->slug = str_slug($stock->name);
        $stock->price = $request->drug_price;
        $stock->quantity = $request->drug_quantity;
        $stock->description = $request->product_description;
        $company->stocks()->save($stock);
        Alert::success('Stock Item has been updated')->flash();
        return back();
    }

    /**
     * Delete a single stock item
     * @param integer $id
     * @return redirect
     */
    public function delete($id){
        $this->stock->getById($id)->delete();
        Alert::info("Stock Item deleted")->flash();
        return redirect()->to('pharmacist/stock');
    }
}
