@extends('backpack::layout')

@section('header')
    <section class="content-header">
        <h1>
            {{ $title }}
        </h1>
        <ol class="breadcrumb">
            <li><a href="{{ url('administrator') }}">{{ config('app.name') }}</a></li>
            <li class="active">Coupons</li>
        </ol>
    </section>
@endsection


@section('content')
    <div class="row">
        <div class="col-md-12">
            <div class="box box-primary">
                <div class="box-header with-border">
                    <button type="button" class="pull-right btn btn-primary btn-md" data-toggle="modal" data-target="#modal-default">
                        <i class="fa fa-tags"></i> New Coupon
                    </button>
                </div>

                <div class="box-body">
                    <div class="table-responsive">
                        <table class="table table-striped">
                            <thead>
                                <th>#</th>
                                <th>Coupon Code</th>
                                <th>Rate (%)</th>
                                <th>Date Created</th>
                                <th></th>
                            </thead>
                            <tbody>
                                @forelse ($coupons as $coupon)
                                    <tr>
                                        <td>{{ $loop->iteration }}</td>
                                        <td>{{ $coupon->code }}</td>
                                        <td>{{ $coupon->rate }}</td>
                                        <td>{{ $coupon->created_at->format('d-m-Y') }}</td>
                                        <td>
                                            <form class="deleteCoupon" action="{{ route('delete_coupon', $coupon->id) }}" method="post">
                                                {{ csrf_field() }}
                                                {{ method_field('delete') }}
                                                <button type="submit" class="btn btn-danger deleteCoupon">
                                                    <i class="fa fa-trash-o"></i>
                                                </button>
                                            </form>
                                        </td>
                                    </tr>
                                @empty
                                    <tr>
                                        <td colspan="100%" class="text-center">No coupon added yet. Add one now.</td>
                                    </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                    {{ $coupons->links() }}
                </div>
            </div>
        </div>
    </div>

    <div class="modal fade" id="modal-default">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span></button>
                    <h4 class="modal-title">New Coupon</h4>
                </div>
                <div class="modal-body">
                    <form action="" method="post" role="form">
                        {{ csrf_field() }}

                        <div class="form-group">
                            <label>Coupon Code <span class="text-danger">*</span></label>
                            <input type="text" name="coupon_code" class="form-control" required autofocus>
                        </div>

                        <div class="form-group">
                            <label>Rate (%)<span class="text-danger">*</span></label>
                            <input type="text" name="coupon_rate" class="form-control" required>
                        </div>
                </div>
                <div class="modal-footer">
                        <button type="button" class="btn btn-default pull-left" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Save</button>
                    </form>
                </div>
            </div>
            <!-- /.modal-content -->
        </div>
        <!-- /.modal-dialog -->
    </div>
    <!-- /.modal -->

    <script>
        $('a#coupons').addClass('active');

        $('button.deleteCoupon').on('click', function(event) {
            event.preventDefault()
            var response = confirm('Do you really want to delete?')
            if (response === true) {
                $('form.deleteCoupon').submit()
            } else {
                return false
            }
        })
    </script>
@endsection
