@extends('backpack::layout')

@section('header')
    <section class="content-header">
      <h1>
        Patients
      </h1>
      <ol class="breadcrumb">
        <li><a href="{{ url('administrator') }}">{{ config('app.name') }}</a></li>
        <li class="active">Patients</li>
      </ol>
    </section>
@endsection


@section('content')
    <div class="row">
        <div class="col-md-12">
            <div class="box box-default">
                <div class="box-header with-border">
                    <button type="button" class="btn btn-info pull-right" data-toggle="modal" data-target="#modal-default">
                        Add New Patient
                    </button>
                </div>

                <div class="box-body">
                    <div class="table-responsive">
                        <table class="table table-striped table-hover table-bordered">
                            <thead>
                                <th class="text-center">#</th>
                                <th class="text-center">Full Name</th>
                                <th class="text-center">Email</th>
                                <th class="text-center">Date Added</th>
                                <th class="text-center"></th>
                            </thead>
                            <tbody>
                                @foreach($patients as $patient)
                                    <tr>
                                        <td class="text-center">{{ $loop->iteration }}</td>
                                        <td class="text-center">{{ $patient->fullname() }}</td>
                                        <td class="text-center">{{ $patient->email }}</td>
                                        <td class="text-center">{{ $patient->created_at->toDateString() }}</td>
                                        <td class="text-center">
                                            <a href="{{ route('viewPatientDetails',['id'=>$patient->id]) }}" class="btn btn-info">Details</a>
                                            <a href="{{ route('deletePatient', ['id' => $patient->id]) }}" class="btn btn-danger delete">
                                                <i class="fa fa-trash"></i>
                                            </a>
                                        </td>
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                    {{ $patients->links() }}
                </div>
            </div>
        </div>
    </div>

    <div class="modal fade" id="modal-default">
      <div class="modal-dialog">
        <div class="modal-content">
          <div class="modal-header">
            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
              <span aria-hidden="true">&times;</span></button>
            <h4 class="modal-title">Add A New Patient</h4>
          </div>
          <div class="modal-body">
            <form action="{{ route('addNewPatient') }}" role="form" method="post">
                {{ csrf_field() }}
                <div class="form-group">
                    <label>First Name</label>
                    <input type="text" name="firstname" placeholder="First Name" class="form-control">
                </div>
                <div class="form-group">
                    <label>Last Name</label>
                    <input type="text" name="lastname" placeholder="Last Name" class="form-control">
                </div>
                <div class="form-group">
                    <label>Email Address</label>
                    <input type="email" name="email" placeholder="Email Address" class="form-control">
                </div>
                <div class="form-group">
                    <label>Password</label>
                    <input type="password" name="password" placeholder="Password" class="form-control">
                </div>
          </div>
          <div class="modal-footer">
            <button type="button" class="btn btn-default pull-left" data-dismiss="modal">Close</button>
            <button type="submit" class="btn btn-primary">Create Account</button>
            </form>
          </div>
        </div>
        <!-- /.modal-content -->
      </div>
      <!-- /.modal-dialog -->
    </div>

@endsection

@section('after_scripts')
<script>
    $(function(){
        $('a.delete').click(function(){
            if (confirm('Sure to delete patient?')) {
                return true;
            } else {
                return false;
            }
        });
    });
</script>
@endsection
