@extends('backpack::layout')

@section('header')
    <section class="content-header">
      <h1>
        Pharmacists <small>Drug store outlets owners</small>
      </h1>
      <ol class="breadcrumb">
        <li><a href="{{ url('administrator') }}">{{ config('app.name') }}</a></li>
        <li class="active">Pharmacists</li>
      </ol>
    </section>
@endsection


@section('content')
    <div class="row">
        <div class="col-md-12">
            <div class="box box-default">
                <div class="box-header with-border">
                    <button type="button" class="btn btn-info pull-right" data-toggle="modal" data-target="#modal-default">
                        Add New Pharmacist
                    </button>
                </div>

                <div class="box-body">
                    <div class="table-responsive">
                        <table class="table table-striped table-hover table-bordered">
                            <thead>
                                <th class="text-center">#</th>
                                <th class="text-center">Full Name</th>
                                <th class="text-center">Email</th>
                                <th class="text-center">Company</th>
                                <th class="text-center">Company State</th>
                                <th class="text-center">Role</th>
                                <th class="text-center"></th>
                            </thead>
                            <tbody>
                                @forelse($pharmacists as $pharmacist)
                                    <tr>
                                        <td class="text-center">{{ $loop->iteration }}</td>
                                        <td class="text-center">{{ title_case($pharmacist->fullname()) }}</td>
                                        <td class="text-center">{{ $pharmacist->email }}</td>
                                        <td class="text-center">{{ ucfirst($pharmacist->company->company_name) }}</td>
                                        <td class="text-center">{{ ucfirst($pharmacist->company->city) }}</td>
                                        <td class="text-center">{{ $pharmacist->role_in_company }}</td>
                                        <td class="text-center">
                                            <a href="{{ route('viewPharmacistDetails',['id'=>$pharmacist->id]) }}"
                                                class="btn btn-info">Details</a>
                                            <a href="{{ route('deletePharmacist', ['id' => $pharmacist->id]) }}" class="btn btn-danger delete">
                                                <i class="fa fa-trash"></i>
                                            </a>
                                        </td>
                                    </tr>
                                @empty
                                    Nothing to show here yet.
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <div class="modal fade" id="modal-default">
      <div class="modal-dialog">
        <div class="modal-content">
          <div class="modal-header">
            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
              <span aria-hidden="true">&times;</span></button>
            <h4 class="modal-title">Add A New Pharmacist</h4>
          </div>
          <div class="modal-body">
            <form action="{{ route('addNewPharmacist') }}" role="form" method="post">
                {{ csrf_field() }}
                <h3>Personal Data</h3>
                <hr>
                <div class="form-group">
                    <label>First Name</label>
                    <input type="text" name="firstname" placeholder="First Name" class="form-control">
                </div>
                <div class="form-group">
                    <label>Last Name</label>
                    <input type="text" name="lastname" placeholder="Last Name" class="form-control">
                </div>
                <div class="form-group">
                    <label>Email Address</label>
                    <input type="email" name="email" placeholder="Email Address" class="form-control">
                </div>
                <div class="form-group">
                    <label>Password</label>
                    <input type="password" name="password" placeholder="Password" class="form-control">
                </div>

                <hr>

                <h3>Company Data</h3>
                <hr>
                <div class="form-group">
                    <label>Company Name</label>
                    <input type="text" name="company_name" placeholder="Pharmacy/Hospital Name" class="form-control">
                </div>
                <div class="form-group">
                    <label>Role In Company</label>
                    <input type="text" name="role_in_company" placeholder="Role In Company" class="form-control">
                </div>
                <div class="form-group">
                    <label>Street Address</label>
                    <input type="text" name="company_street" placeholder="Street address of pharmacy" class="form-control">
                </div>
                <div class="form-group">
                    <label>City</label>
                    <input type="text" name="company_city" placeholder="City of company" class="form-control">
                </div>
                <div class="form-group">
                    <label>State</label>
                    <input type="text" name="company_state" placeholder="State of company" class="form-control">
                </div>
                <div class="form-group">
                    <label>Delivery Hours</label>
                    <div class="row">
                        <div class="col-sm-6">
                            <label>Start Time</label>
                            <select name="start_delivery" class="form-control">
                                @for ($i = 7; $i <= 11; $i++)
                                    <option value="{{ $i.'am' }}">{{ $i.'am' }}</option>
                                @endfor
                            </select>
                        </div>
                        <div class="col-sm-6">
                            <label>Closing Time</label>
                            <select name="end_delivery" class="form-control">
                                <option value="12pm">12pm</option>
                                @for ($i = 1; $i <= 9; $i++)
                                    <option value="{{ $i.'pm' }}">{{ $i.'pm' }}</option>
                                @endfor
                            </select>
                        </div>
                    </div>
                </div>
                <div class="form-group">
                    <label for="deliveryInfo">Delivery Info</label>
                    <textarea name="delivery_info" id="deliveryInfo" rows="4" class="form-control"></textarea>
                </div>
          </div>
          <div class="modal-footer">
            <button type="button" class="btn btn-default pull-left" data-dismiss="modal">Close</button>
            <button type="submit" class="btn btn-primary">Create Account</button>
            </form>
          </div>
        </div>
        <!-- /.modal-content -->
      </div>
      <!-- /.modal-dialog -->
    </div>

@endsection

@section('after_scripts')
<script>
    $(function(){
        $('a.delete').click(function(){
            var res = confirm('Sure to delete pharmacist?');
            if (res) {
                return true;
            } else {
                return false;
            }
        });
    });
</script>
@endsection
