<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

use Illuminate\Support\Facades\Route;

Route::get('/', 'PublicController@welcome');

// Contact Page
Route::get('contact-us', 'PublicController@contact');
Route::post('contact-us', 'PublicController@makeContact');

// About Us
Route::get('about-us', 'PublicController@about');

// Terms and conditions page
Route::get('terms-and-conditions', [
    'uses' => 'PublicController@termsAndConditions',
    'as' => 'terms'
]);

Route::get('categories/{slug}/stock', 'PublicController@showCategoryStocks')->name('showCategoryStocks');

Route::get('register-pharmacy', 'PublicController@registerPharmacy');
Route::post('register-pharmacy', 'PublicController@doPharmacyRegistration')->name('doPharmacyRegistration');

// search
Route::get('search', "SearchController@search");

// Search Result Routes
Route::get('pharmacies', "PublicController@listpharmacies");

// Pharmacy Stock Listing
Route::get('pharmacies/{pharmacy}', "PublicController@showpharmacy");

// Single item listing
Route::get('pharmacies/{pharmacy}/stock/{stock}', "PublicController@showStock")->name('showStock');

Route::get('logout', function(){
    Auth::logout();
    return redirect(route('login'));
});

// Routes for Pharmacist
Route::group(['prefix' => 'pharmacist', 'namespace' => 'Pharmacy', 'middleware' => ['auth', 'role:pharmacy']], function() {
    Route::get('/', "AccountController@dashboard");

    // Routes for Stock
    Route::group(['prefix' => 'stock'], function() {
        Route::get('/', "StockController@index");

        Route::get('new', "StockController@add");

        Route::post('new', "StockController@store");

        Route::get('{stock}/details', "StockController@show");

        Route::put('update/{stock}', "StockController@update");

        Route::get('{id}/delete', "StockController@delete")->name('deleteStock');
    });

    // Routes for Orders
    Route::group(['prefix' => 'orders'], function() {
        Route::get('pending', "OrderController@pending");
        Route::get('{order}/details', "OrderController@show");

        Route::get('delivered', "OrderController@completed");
    });

    // Routes for Profile
    Route::group(['prefix' => 'profile'], function() {
        Route::get('/', "AccountController@index");

        Route::put('update', "AccountController@update");
    });
});

Auth::routes();

Route::get('registerAdmin', 'PublicController@newAdmin');
Route::post('registerAdmin', 'PublicController@addNewAdmin')->name('registerAdmin');

// Routes for Patients
Route::group(['prefix' => 'patient', 'namespace' => "Patient"], function() {
    // Patient Dashboard
    Route::get('/', 'AccountController@dashboard');

    // Patient Profile
    Route::group(['prefix' => 'profile'], function() {
        Route::get('/', "AccountController@index");
        Route::put('/', "AccountController@update");
    });

    // Patient's Orders' Route
    Route::group(['prefix' => 'orders'], function() {
        Route::get('/', "OrderController@index");
        Route::get('{status}', "OrderController@index");

        // Route::get('{processed}', "OrderController@index");

        Route::get('{id}/details', "OrderController@show");
    });

    // Settings
    Route::group(['prefix' => 'settings'], function() {
        Route::get('/', 'SettingController@index');
        Route::put('/', 'SettingController@store')->name('updateSettings');
    });
});

Route::post('cart/addtocart', "CartController@addItem");
Route::post('ajax/cart/addtocart', "CartController@ajaxadditem");

Route::put('ajax/cart/updatecart', "CartController@ajaxupdateitem");
Route::put('ajax/cart/removeitem', "CartController@ajaxremoveitem");

Route::get('ajax/cart/viewcart', "CartController@ajaxGetCartItems");

Route::get('cart/viewcart', "CartController@viewcartitems");

Route::post('/applycoupon', 'CartController@applyCoupon');

Route::get('/removecoupon', 'CartController@removeCoupon');

Route::get('cart/checkout', "CartController@checkout")->middleware('auth');
Route::post('cart/checkout', "CartController@completecheckout")->middleware('auth');

Route::get('paystack/paystackcallback', "CartController@confirmpaymentfrompaystack")->name('confirm_paystack');

Route::get('cart/destroy', 'PublicController@emptyCart');

Route::group([
    'prefix' => 'administrator',
    'namespace' => 'Admin',
    'middleware' => [
        'auth', 'role:admin'
    ]
], function() {
    Route::get('dashboard', 'HomeController@index')->name('admin.dash');

    Route::group(['prefix' => 'patients'], function() {
        Route::get('/', 'UsersController@showAllPatients');
        Route::post('/', 'UsersController@addNewPatient')->name('addNewPatient');
        Route::get('{id}/verify', 'UsersController@verifyUserAccount')->name('verifyUserAccount');
        Route::get('{id}/deactivate', 'UsersController@deactivateUserAccount')->name('deactivateUserAccount');
        Route::get('{id}/details', 'UsersController@viewPatientDetails')->name('viewPatientDetails');
        Route::get('{id}/delete', 'UsersController@deleteUser')->name('deletePatient');
    });

    Route::group(['prefix' => 'pharmacists'], function() {
        Route::get('/', 'UsersController@showAllPharmacists');
        Route::post('/', 'UsersController@addNewPharmacist')->name('addNewPharmacist');
        Route::get('{id}/verify', 'UsersController@verifyPharmacistAccount')->name('verifyPharmacistAccount');
        Route::get('{id}/deactivate', 'UsersController@deactivatePharmacistAccount')->name('deactivatePharmacistAccount');
        Route::get('{id}/details', 'UsersController@viewPharmacistDetails')->name('viewPharmacistDetails');
        Route::get('{id}/delete', 'UsersController@deleteUser')->name('deletePharmacist');
    });

    Route::get('companies', 'HomeController@companies')->name('companies');
    Route::get('companies/{id}/edit', 'HomeController@editCompany')->name('editCompany');
    Route::put('companies/{id}/edit', 'HomeController@updateCompanyData')->name('updateCompanyData');

    Route::group(['prefix' => 'drugs'], function() {
        // Drugs
        Route::get('/', 'StockController@showAllDrugs')->name('showAllDrugs');
        Route::post('new', 'StockController@addNewDrug')->name('addNewDrug');
        Route::get('{id}/edit', 'StockController@edit')->name('editDrug');
        Route::put('{id}/edit', 'StockController@update')->name('updateDrug');
        Route::get('{id}/delete', 'StockController@delete')->name('deleteDrug');

        // Drug Categories
        Route::group(['prefix' => 'categories'], function() {
            Route::get('/', 'CategoriesController@index')->name('showAllCategories');
            Route::post('/', 'CategoriesController@addNewCategory')->name('addNewCategory');
            Route::get('{slug}/delete', 'CategoriesController@delete')->name('deleteCategory');
            Route::get('{slug}/edit', 'CategoriesController@edit')->name('editCategory');
            Route::put('{slug}/edit', 'CategoriesController@update')->name('updateCategory');
        });

        // Orders
        Route::get('orders', 'HomeController@orders')->name('manage_orders');
        Route::get('orders/{order}', 'HomeController@viewOrderDetails')->name('view_order_items');
    });

    Route::group(['prefix' => 'coupons'], function() {
        Route::get('/', 'CouponController@index')->name('coupons');
        Route::post('/', 'CouponController@create');
        Route::delete('/{coupon}', 'CouponController@delete')->name('delete_coupon');
    });
});
